"""
:authors: Peoplees
:license: Apache License, Version 2.0, see LICENSE file

:copyright: (c) 2024 Peoplees
"""

from .Numbers1 import *
from .Numbers2 import *
from .Numbers3 import *
from .Numbers4 import *

__author__ = 'Peoplees'
__version__ = '1.0.0'
__email__ = 'pulyatv1@gmail.com'